%define name    vigra
%define version 1.8.0
%define release %mkrel 7
%define major   2
%define libname %mklibname %{name} %{major}
%define olddevel %libname-devel
%define libnamedevel %mklibname %{name} -d

Name:           %{name}
Version:        %{version}
Release:        %{release}
Summary:        Generic Programming for Computer Vision
License:        MIT
Group:          Development/C
Source0:        http://kogs-www.informatik.uni-hamburg.de/~koethe/vigra/%{name}-%{version}-src.tar.gz
Patch0:		vigra-1.8.0.gcc47.patch
URL:            http://kogs-www.informatik.uni-hamburg.de/~koethe/vigra/
BuildRequires:  zlib-devel libjpeg-devel libpng-devel libtiff-devel fftw-devel >= 3
BuildRequires:  cmake hdf5-devel boost-devel doxygen python-sphinx python-numpy-devel

%description
VIGRA stands for "Vision with Generic Algorithms". It's a novel computer vision
library that puts its main emphasis on customizable algorithms and data
structures. By using template techniques similar to those in the C++ Standard
Template Library, you can easily adapt any VIGRA component to the needs of your
application without thereby giving up execution speed.

%package devel
Summary: Development tools for programs which will use the vigra library
Group: Development/C
Requires: vigra = %{version}-%{release}
Requires: libjpeg-devel libtiff-devel libpng-devel zlib-devel fftw-devel >= 3
Requires: hdf5-devel boost-devel python-sphinx python-numpy

%description devel
The vigra-devel package includes the header files necessary for developing
programs that use the vigra library.

%package python
Summary: Python interface for the vigra computer vision library
Group: Development/Python
Requires: vigra = %{version}-%{release}
Requires: python-numpy-devel 

%description python
The vigra-python package provides python bindings for vigra

%prep
%setup -q -n %{name}-%{version}
%patch0 -p1

%build
%cmake -DDOCINSTALL=share/doc/%{name} \
%if "%{_lib}" == "lib64"
       -DLIBDIR_SUFFIX=64 \
%endif

%make VERBOSE=1
# cleanup
rm -f doc/vigranumpy/.buildinfo

%install
%makeinstall_std -C build

%files
%{_libdir}/libvigraimpex.so.*

%files devel
%doc %{_datadir}/doc/%{name}
%{_bindir}/vigra-config
%{_includedir}/vigra
%{_libdir}/libvigraimpex.so
%{_libdir}/vigra
%doc doc/vigra doc/vigranumpy

%files python
%{python_sitearch}/vigra


%changelog

* Thu Apr 11 2013 ennael <ennael> 1.8.0-7.mga3
+ Revision: 409506
- rebuild for boost-1.53

* Mon Jan 14 2013 umeabot <umeabot> 1.8.0-6.mga3
+ Revision: 385413
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Dec 20 2012 fwang <fwang> 1.8.0-5.mga3
+ Revision: 333125
- rebuild for new boost

* Fri Aug 03 2012 fwang <fwang> 1.8.0-4.mga3
+ Revision: 278116
- fix build with gcc 4.7
- rebuild for new boost

* Wed May 30 2012 fwang <fwang> 1.8.0-3.mga3
+ Revision: 250140
- rebuild for new boost

* Sun Dec 25 2011 fwang <fwang> 1.8.0-2.mga2
+ Revision: 187454
- rebuild for new lbitiff

* Sun Dec 11 2011 eatdirt <eatdirt> 1.8.0-1.mga2
+ Revision: 180500
- Upgrade to 1.8.0

* Mon Nov 28 2011 fwang <fwang> 1.7.1-3.mga2
+ Revision: 173669
- rebuild for new boost

* Sun Sep 11 2011 grenoya <grenoya> 1.7.1-2.mga2
+ Revision: 142487
- replace require of numpy and numpy-f2py by python-numpy-devel (it contains f2py and will pull python-numpy)

* Sun Sep 11 2011 fwang <fwang> 1.7.1-1.mga2
+ Revision: 142330
- fix group
- update file list
- update file list
- clean spec
- update file list
- new version 1.7.1
- add gentoo patch to build with libpng1.5
- add more br
- fix br
- rebuild for new libpng

  + dmorgan <dmorgan>
    - New version 1.7.0
      Sync with fedora

* Sun Jan 23 2011 dmorgan <dmorgan> 1.5.0-7.mga1
+ Revision: 34527
- Remove mdv macros
- add %%{name}-devel on the devel package
- imported package vigra


* Sat Dec 04 2010 Oden Eriksson <oeriksson@mandriva.com> 1.5.0-7mdv2011.0
+ Revision: 608124
- rebuild

* Sun Jan 10 2010 Oden Eriksson <oeriksson@mandriva.com> 1.5.0-6mdv2010.1
+ Revision: 488807
- rebuilt against libjpeg v8

* Wed Sep 09 2009 Thierry Vignaud <tv@mandriva.org> 1.5.0-5mdv2010.0
+ Revision: 434673
- rebuild
- rebuild

* Wed Jul 30 2008 Thierry Vignaud <tv@mandriva.org> 1.5.0-3mdv2009.0
+ Revision: 255552
- rebuild

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Fri Dec 21 2007 Olivier Blin <oblin@mandriva.com> 1.5.0-1mdv2008.1
+ Revision: 136570
- restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Mon Jul 23 2007 Couriousous <couriousous@mandriva.org> 1.5.0-1mdv2008.0
+ Revision: 54863
- 1.5.0
- Import vigra



* Sun Apr  2 2006 Couriousous <couriousous@mandriva.org> 1.4.0-1mdk
- 1.4.0

* Sat Oct  1 2005 Couriousous <couriousous@mandriva.org> 1.3.3-1mdk
- 1.3.3
- fix some warning

* Fri Jun 17 2005 Couriousous <couriousous@mandriva.org> 1.3.2-2mdk
- Rebuild

* Sun Apr 03 2005 Couriousous <couriousous@mandrake.org> 1.3.2-1mdk
- New Release
- Multiarch

* Sun Jan 23 2005 Couriousous <couriousous@mandrake.org> 1.3.1-1mdk
- New Release

* Thu Dec 08 2004 Couriouous <couriousous@mandrake.org> 1.3.0-1mdk
- 1.3.0
- Remove patch0, merged upstream

* Thu Jul 01 2004 Guillaume Rousse <guillomovitch@mandrake.org> 1.2.0-4mdk 
- more complete patch from upstream

* Wed Jun 09 2004 Guillaume Rousse <guillomovitch@mandrake.org> 1.2.0-3mdk 
- fixed build
- rpmbuildupdate aware
- dropped patch0

* Sat Mar 13 2004 Guillaume Rousse <guillomovitch@mandrake.org> 1.2.0-2mdk
- fix link

* Mon Jan 12 2004 Guillaume Rousse <guillomovitch@mandrake.org> 1.2.0-1mdk
- first mdk package (leafred <fred@lea-linux.org>)
